Introduction — pynexusic 2.5.0 documentation

# Introduction

pynexusic is a package that allows communication with the following tools:

1. Wood NEXUS IC

2. Maximo

3. OSI PI

4. Documentum

Each one of these tools has a separate class that can be used to build the connector.

# Python library installation

    pip install pynexusic

# Library documentation

Steps to launch library documentation

> 1. Import `utils`

>    >     from pynexusic import utils

> 2. Launch documentation

>    >     utils.launchDocs()

# External documentation

- NEXUS IC

  > NEXUS IC REST API documentation can be found in the following link:

  > https://docs.nexusic.com/

- OSI PI

  > OSI PI API documentation can be found in the following link:

  > https://techsupport.osisoft.com/Documentation/PI-Web-API/help.html

- Maximo

  > Maximo API documentation can be found in the following link:

  > https://www.ibm.com/support/knowledgecenter/SS8CCV_7.6.0.8/com.ibm.mams.doc/overview/c_product_overview.html

# License

This project is licensed under the MIT license.